@@ -16,11 +16,11 @@ class init:
 		return text
 
 	def terminate(self, username):
-		res = requests.post(f"{url}/terminate/{username}/${self.uid}")
+		res = requests.post(f"{url}/terminate/{username}/{self.uid}")
 		text = res.text()
 		return text
 
 	def unterminate(self, username):
-		res = requests.post(f"{url}/unterminate/{username}/${self.uid}")
+		res = requests.post(f"{url}/unterminate/{username}/{self.uid}")
 		text = res.text()
 		return text
\ No newline at end of file
